#!/bin/bash

ss7box_dir=../ss7box

sangoma_isup_dirname=xygisup
sangoma_isup_dir=../$sangoma_isup_dirname

function debug
{
	ls -l ~/svn/trunk/xygisup/smgcfg*
	echo "press Enter to continue; ctl-c to quit"
	read $blah
}

function copy_file
{
	echo "copy $1 to $2"
	if [ -z $1 ] || [ ! -e $1 ] ; then
		echo "missing file: $1"
		exit 1
	fi
	if [ ! -d $2 ] ; then
		echo "missing directory: $2"
		if [ -e $2 ] ; then
			echo "overwriting existing file $2"
		else
			exit 1
		fi
	fi
	if ! cp $1 $2 ; then
		echo "copy failed"
		exit 1
	fi
	
	return 0
}

function build_release
{
	homedir=$PWD
	cd $sangoma_isup_dir
	../auth/build.py -s $1
	make clean
	make deps
	make
	cd $ss7box_dir
	make clean deps all
	cd $homedir	
}

function copy_release_components
{
	echo "copying release components"
	pwd
	rm -f ./notes/*
	rm -f ./new/*
	rm -f *.conf
	rm -f smgcfg*.py
	
	copy_file $sangoma_isup_dir/smgcfg04.py .
	copy_file $sangoma_isup_dir/smgcfg05.py .
	copy_file $sangoma_isup_dir/smgcfg06.py .
	copy_file $sangoma_isup_dir/smgcfg07.py .
	copy_file $sangoma_isup_dir/smgcfg08.py .
	
#	copy_file $ss7box_dir/ss7box.conf .
#	copy_file $ss7box_dir/ss7box.conf ./new
	
	copy_file $ss7box_dir/cli/ss7box_cli .
	copy_file $ss7box_dir/cli/ss7box_cli ./new
	./ss7box_cli --ver
	copy_file $ss7box_dir/cli/ss7box_cli.conf .
	copy_file $ss7box_dir/cli/ss7box_cli.conf ./new
	
	copy_file $sangoma_isup_dir/sangoma_isupd .
	copy_file $sangoma_isup_dir/sangoma_isupd ./new
	./sangoma_isupd --ver
#	copy_file $sangoma_isup_dir/sangoma_isup.conf .
#	copy_file $sangoma_isup_dir/sangoma_isup.conf ./new
#	copy_file $sangoma_isup_dir/tg*.conf ./new
	copy_file $sangoma_isup_dir/RELEASE_NOTES.sangoma_isup.txt ./notes
	
	copy_file $sangoma_isup_dir/cli/sangoma_isup_cli .
	copy_file $sangoma_isup_dir/cli/sangoma_isup_cli ./new
	./sangoma_isup_cli --ver
	copy_file $sangoma_isup_dir/cli/sangoma_isup_cli.conf .
	copy_file $sangoma_isup_dir/cli/sangoma_isup_cli.conf ./new
	copy_file $sangoma_isup_dir/cli/RELEASE_NOTES.sangoma_isup_cli.txt ./notes/
	
	copy_file $sangoma_isup_dir/cdr/cdr_logger .
	copy_file $sangoma_isup_dir/cdr/cdr_logger ./new
	./cdr_logger --ver
	copy_file $sangoma_isup_dir/cdr/cdr_logger.conf .
	copy_file $sangoma_isup_dir/cdr/cdr_logger.conf ./new
	copy_file $sangoma_isup_dir/cdr/RELEASE_NOTES.sangoma_isup_cdr.txt ./notes/
	
	rm *~
}

function tarball
{
	echo tarball
#  	if [ -z $1 ] ; then
# 		echo "Missing revision string."
# 		exit 1
# 	fi
 	rm -f *~ smginstall*.tgz
	cd ..
	mv smginstall/ smginstall-$2-$1/
	ls -l smginstall-$2-$1/
 	tar czvf smginstall-$2-$1.tgz smginstall-$2-$1/
	mv smginstall-$2-$1/ smginstall/
	pwd
	cd smginstall/
	pwd
}

# main

rm -f $sangoma_isup_dir/site_notices/*
datestring=$(date +%F)
site_notice_itu=$sangoma_isup_dirname/site_notices/site-m3ua-itu.txt
site_notice_ansi=$sangoma_isup_dirname/site_notices/site-m3ua-ansi.txt

# make ANSI release
build_release "m3ua-ansi"
debug
copy_release_components
debug
tarball "ANSI" $datestring
debug

# make ITU release
build_release "m3ua-itu"
debug
copy_release_components
debug
tarball "ITU" $datestring
debug

cd ..
ls -l $site_notice_itu
echo
cat $site_notice_itu
echo
ls -l $site_notice_ansi
echo
cat $site_notice_ansi
echo
mv smginstall-$datestring-ITU.tgz smginstall/
mv smginstall-$datestring-ANSI.tgz smginstall/
cd smginstall
ls -l smginstall-$datestring*
